#ifdef GL_ES
precision mediump float;
#endif

uniform float u_time;
uniform vec2 u_resolution;

float circleSDF(vec2 c, float r, vec2 pos) {
    return length(pos - c) - r;
}

float SDF(vec2 pos) 
{
    return circleSDF(vec2(0), 0., pos);
}

float movingCircle(vec2 pos, vec2 pos0, float offset)
{
    float d = sin(10. * (SDF(pos) * exp(-length(pos0)*3.) + .2* u_time + offset));
    d = abs(d);
    d = smoothstep(0., .2, d);
    return 1. - d;
}

void mainImage( out vec4 fragColor, in vec2 fragCoord )
{
    // Normalized pixel coordinates (from 0 to 1)
    vec2 uv = (fragCoord - .5 * u_resolution.xy)/u_resolution.y;
    vec2 uv0 = uv;
    uv = fract(uv*100000000.)-.5;

    float dr = movingCircle(uv, uv0, -.01);
    
    float dg = movingCircle(uv, uv0, .0);
    
    float db = movingCircle(uv, uv0, .01);
    
    vec3 col = vec3(dr, dg, db);

    // Output to screen
    if (length(uv0) < 1000.) {
        fragColor = vec4(col,1.0);
    } else {
	fragColor = vec4(0., 0., 0., 1.);
    }
}

void main() {
    mainImage(gl_FragColor, gl_FragCoord.xy);
}
